#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 binary-conduit
version:              1.3.1
visibility:           public
id:                   binary-conduit-1.3.1-oC5VAjmVAD5C0Kv8Xr9qO
key:                  binary-conduit-1.3.1-oC5VAjmVAD5C0Kv8Xr9qO
license:              MIT
copyright:            2013 Alexander Vershilov
maintainer:           alexander.vershilov@gmail.com
author:               Alexander Vershilov
stability:            Experimental
homepage:             http://github.com/qnikst/binary-conduit/
synopsis:             data serialization/deserialization conduit library
description:
    The binary-conduit package.
    Allow binary serialization using iterative conduit interface.

category:             Conduit
abi:                  3569d2b7ca4082542da3bed4b0541f89
exposed:              True
exposed-modules:      Data.Conduit.Serialization.Binary
import-dirs:          /usr/lib/ghc-9.6.6/site-local/binary-conduit-1.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/binary-conduit-1.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/binary-conduit-1.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-binary-conduit
hs-libraries:         HSbinary-conduit-1.3.1-oC5VAjmVAD5C0Kv8Xr9qO
depends:
    base-4.18.2.1 binary-0.8.9.1 bytestring-0.11.5.3
    conduit-1.3.6.1-1yIrQJAoba7Gda6MAs4N1q exceptions-0.10.7
    vector-0.13.2.0-5hQDxYlIzjI43Z4IxwIpHc

haddock-interfaces:
    /usr/share/doc/haskell-binary-conduit/html/binary-conduit.haddock

haddock-html:         /usr/share/doc/haskell-binary-conduit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

